@@ -8,26 +8,26 @@
 """
 # flake8: noqa
 
-import pathlib
-
 
 STYLESHEETS = [
     data("css/bootstrap.min.css"),
     data("css/fix.css"),
     data("cubes.bootstrap.css"),
     data("cubicweb.pictograms.css"),
-    "https://cdn.jsdelivr.net/npm/@engie-group/fluid-design-system@latest/lib/fluid-design-system.css",
+    "https://cdn.jsdelivr.net/npm/@engie-group/fluid-design-system@v4.10.1/lib/fluid-design-system.css",
     "https://fonts.googleapis.com/css?family=Material+Icons|Lato:300,400,700,900&display=swap",
 ]
 
-CW_COMPAT_STYLESHEETS = [data("cubes.bootstrap.cw_compat.css")]
+CW_COMPAT_STYLESHEETS = [
+    data("cubes.bootstrap.cw_compat.css")
+]
 
 JAVASCRIPTS.extend(
     (
         data("js/bootstrap.min.js"),
         data("cubes.bootstrap.js"),
         data("cubes.squareui.js"),
-        "https://cdn.jsdelivr.net/npm/@engie-group/fluid-design-system@latest/lib/fluid-design-system.js",
-        "https://cdn.jsdelivr.net/npm/@engie-group/fluid-design-system@latest/lib/auto-init.js",
+        "https://cdn.jsdelivr.net/npm/@engie-group/fluid-design-system@v4.10.1/lib/fluid-design-system.js",
+        "https://cdn.jsdelivr.net/npm/@engie-group/fluid-design-system@v4.10.1/lib/auto-init.js",
     )
 )
