@@ -6,10 +6,10 @@
 
 from logilab.common.decorators import monkeypatch
 
-from cubicweb import view as cwview
+from cubicweb_web import view as cwview
 from cubicweb.schema import display_name
-from cubicweb.web.views.basetemplates import HTMLHeader
-from cubicweb.web.views.boxes import ContextualBoxLayout, contextual
+from cubicweb_web.views.basetemplates import HTMLHeader
+from cubicweb_web.views.boxes import ContextualBoxLayout, contextual
 
 # do not wrap cell_calls with <div class="section">
 
