@@ -7,6 +7,6 @@
 
 __docformat__ = "restructuredtext en"
 
-from cubicweb.web.views import facets
+from cubicweb_web.views import facets
 
 facets.FilterBox.bk_linkbox_template = '<div class="facet-action">%s</div>'
