@@ -25,7 +25,7 @@ from logilab.mtconverter import xml_escape
 
 from cubicweb import tags
 from cubicweb.utils import support_args
-from cubicweb.web.views import formrenderers
+from cubicweb_web.views import formrenderers
 
 
 @monkeypatch(formrenderers.EntityCompositeFormRenderer)
