@@ -9,8 +9,8 @@ __docformat__ = "restructuredtext en"
 
 from logilab.common.decorators import monkeypatch
 
-from cubicweb.web import htmlwidgets
-from cubicweb.web.component import Separator
+from cubicweb_web import htmlwidgets
+from cubicweb_web.component import Separator
 
 
 @monkeypatch(Separator)
