@@ -10,7 +10,7 @@ __docformat__ = "restructuredtext en"
 from logilab.common.decorators import monkeypatch
 
 from cubicweb.entity import Entity
-from cubicweb.web.views import ibreadcrumbs
+from cubicweb_web.views import ibreadcrumbs
 
 
 ibreadcrumbs.BreadCrumbEntityVComponent.css_class = "breadcrumb"
