@@ -8,9 +8,8 @@
 __docformat__ = "restructuredtext en"
 
 from logilab.common.decorators import monkeypatch
-from logilab.mtconverter import xml_escape
 
-from cubicweb.web.views import primary
+from cubicweb_web.views import primary
 
 
 @monkeypatch(primary.PrimaryView)
