@@ -6,7 +6,7 @@
 """
 __docformat__ = "restructuredtext en"
 
-from cubicweb.web.views.reledit import AutoClickAndEditFormView
+from cubicweb_web.views.reledit import AutoClickAndEditFormView
 
 AutoClickAndEditFormView._addzone = ' <span class="glyphicon glyphicon-plus"></span>'
 AutoClickAndEditFormView._deletezone = (
