@@ -11,9 +11,14 @@ __docformat__ = "restructuredtext en"
 
 class DropDownBox(object):
     ul_template = """
-    <a class="dropdown-toggle %(klass)s" data-toggle="dropdown" href="#">
-    %(title)s<span class="caret"></span></a>
-    <ul class="dropdown-menu" role="menu">%(actions)s</ul>"""
+    <div class="nj-avatar nj-avatar--sm">
+        <div class="nj-avatar__picture" data-toggle="collapse" href="#dropdownMenu" aria-expanded="false" aria-controls="dropdownMenu" role="button">
+            <div class="nj-avatar__initials">%(title)s</div>
+        </div>
+        <div class="nj-collapse" id="dropdownMenu">
+            <ul class="dropdown-menu nj-list-group nj-list-group--sm nj-list-group--no-border" role="menu">%(actions)s</ul>
+        </div>
+    </div>"""
 
     li_template = "<li>%(link)s<li>"
 
@@ -29,7 +34,6 @@ class DropDownBox(object):
             self.ul_template
             % {
                 "title": self.title,
-                "klass": self.klass,
                 "actions": "".join(self.render_items()),
             }
         )
